@@ -1,7 +1,7 @@
 import inspect
 from .smarterStore import SmarterStore
 from abc import ABCMeta, abstractmethod
-from typing import Callable, Optional, Any, Tuple, List
+from typing import Callable, Optional, Any, Tuple
 
 
 class SmarterMessage(dict):
@@ -248,7 +248,8 @@ class SmarterSender:
         user_id = return_message.get("user", {}).get("id")
         return self.__get_usage(user_id=user_id)
 
-    def query_data_lake(self, sql_query: str, args=None, paramstyle: str = "format", commit=True) -> Tuple:
+    def query_data_lake(self, sql_query: str, parameters=None, paramstyle: str = "format", commit=True, *args,
+                        **kwargs) -> Tuple:
         """
         Takes an SQL query on the data lake and returns all remaining rows of a query result.
         Args:
@@ -266,13 +267,15 @@ class SmarterSender:
             making up a row.:tuple
         """
         data = self.__db.execute_sql_query(query=sql_query,
-                                           args=args,
+                                           parameters=parameters,
                                            paramstyle=paramstyle,
                                            commit=commit,
-                                           fetch="all")
+                                           fetch="all",
+                                           *args,
+                                           **kwargs)
         return data
 
-    def write_dataframe_to_lake(self, df, table_name: str) -> None:
+    def write_dataframe_to_lake(self, dataframe, table_name: str, commit=True, *args, **kwargs) -> None:
         """
         Inserts a :class:`pandas.DataFrame` into an table within the current dat lake.
         Args:
@@ -281,33 +284,11 @@ class SmarterSender:
              :param table_name: str
                  The name of the table to insert to in the lake.
          """
-        self.__db.write_from_dataframe(df=df, table_name=table_name)
-
-    def bulk_insert_to_lake(self, file_name: str, table_name: str, delimiter: str, column_names: List[str],
-                            parameter_indices: List[int], batch_size: int = 1) -> None:
-        """
-        Runs a single bulk insert statement into the data lake from a CSV FILE.
-        Args:
-             :param file_name: str
-                 The name of the CSV file to read from.
-             :param table_name: str
-                 The name of the table to insert to.
-             :param column_names:list
-                 The name of the columns in the table to insert to.
-             :param parameter_indices:list
-                 The indexes of the columns in the file to insert to.
-             :param delimiter: str
-                 The delimiter to use when reading the file.
-            :param batch_size: int
-                The number of rows to insert per insert statement. Minimum allowed value is 1.
-        """
-
-        self.__db.bulk_insert(file_name=file_name,
-                              table_name=table_name,
-                              batch_size=batch_size,
-                              delimiter=delimiter,
-                              parameter_indices=parameter_indices,
-                              column_names=column_names)
+        self.__db.write_from_dataframe(dataframe=dataframe,
+                                       table_name=table_name,
+                                       commit=commit,
+                                       *args,
+                                       **kwargs)
 
 
 class _Smarter_SignatureCheckerMeta(ABCMeta):
